@@ -1,6 +1,6 @@
 ;;; elisp-dev-mcp.el --- MCP server for agentic Elisp development -*- lexical-binding: t -*-
 
-;; Copyright (C) 2025-2026 elisp-dev-mcp.el contributors
+;; Copyright (C) 2025 Laurynas Biveinis
 
 ;; This file is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
 ;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 ;; Author: Laurynas Biveinis
-;; Package-Version: 1.2.0
-;; Package-Revision: acce467f667d
+;; Package-Version: 20251004.1154
+;; Package-Revision: 05bc3ca843eb
 ;; Package-Requires: ((emacs "27.1") (mcp-server-lib "0.2.0"))
 ;; Keywords: tools, development
 ;; URL: https://github.com/laurynas-biveinis/elisp-dev-mcp
@@ -32,7 +32,6 @@
 (require 'help-fns)
 (require 'pp)
 (require 'info-look)
-(require 'cl-lib)
 
 
 ;;; System Directory Setup
@@ -49,50 +48,12 @@ Computed once at package load time from `data-directory'.")
 (defconst elisp-dev-mcp--server-id "elisp-dev-mcp"
   "Server ID for this MCP server.")
 
-(defgroup elisp-dev-mcp nil
-  "MCP server for agentic Elisp development."
-  :group 'tools
-  :prefix "elisp-dev-mcp-")
-
-(defcustom elisp-dev-mcp-additional-allowed-dirs nil
-  "Additional directories to allow for elisp-read-source-file.
-List of directory paths that should be accessible in addition to
-the default Emacs system and ELPA directories.
-
-This is useful for users of alternative package managers like
-straight.el, elpaca, or custom package setups.
-
-Example:
-  (setq elisp-dev-mcp-additional-allowed-dirs
-        \\='(\"~/.emacs.d/straight/build/\"
-           \"~/.emacs.d/straight/repos/\"
-           \"~/my-elisp-packages/\"))
-
-Security note: Only add directories you trust, as this allows
-the MCP server to read any .el files in these locations."
-  :type '(repeat directory)
-  :group 'elisp-dev-mcp
-  :safe (lambda (val) (and (listp val) (cl-every #'stringp val))))
-
 ;;; Utility Functions
 
 (defun elisp-dev-mcp--non-empty-docstring-p (doc)
   "Return t if DOC is a non-empty documentation string, nil otherwise."
   (and doc (not (string-empty-p doc))))
 
-(defmacro elisp-dev-mcp--with-auto-compression (&rest body)
-  "Execute BODY with `auto-compression-mode' temporarily enabled.
-Restores the original mode state after BODY completes."
-  (declare (indent 0) (debug t))
-  `(let ((elisp-dev-mcp--was-enabled auto-compression-mode))
-     (unwind-protect
-         (progn
-           (unless elisp-dev-mcp--was-enabled
-             (auto-compression-mode 1))
-           ,@body)
-       (unless elisp-dev-mcp--was-enabled
-         (auto-compression-mode -1)))))
-
 ;;; JSON Response Helpers
 
 (defun elisp-dev-mcp--json-encode-source-location
@@ -420,55 +381,43 @@ MCP Parameters:
   "Extract function definition for FN-NAME from FUNC-FILE.
 SYM is the function symbol.
 IS-ALIAS and ALIASED-TO are used for special handling of aliases."
-  (elisp-dev-mcp--with-auto-compression
-    (let ((actual-file
-           (cond
-            ((file-exists-p func-file)
-             func-file)
-            ((file-exists-p (concat func-file ".gz"))
-             (concat func-file ".gz"))
-            (t
-             (mcp-server-lib-tool-throw
-              (format "File not found: %s (tried .el and .el.gz)"
-                      func-file))))))
-      (with-temp-buffer
-        (insert-file-contents actual-file)
-        (goto-char (point-min))
-        (let ((def-pos
-               (find-function-search-for-symbol sym nil func-file)))
-          (unless def-pos
-            (mcp-server-lib-tool-throw
-             (format "Could not locate definition for %s" fn-name)))
-          (goto-char (cdr def-pos))
+  (with-temp-buffer
+    (insert-file-contents func-file)
+    (goto-char (point-min))
+    (let ((def-pos
+           (find-function-search-for-symbol sym nil func-file)))
+      (unless def-pos
+        (mcp-server-lib-tool-throw
+         (format "Could not locate definition for %s" fn-name)))
+      (goto-char (cdr def-pos))
 
-          ;; Find the start point including any header comments
-          (let* ((func-point (point))
-                 (start-point
-                  (elisp-dev-mcp--find-header-comment-start
-                   func-point))
-                 (end-point
-                  (progn
-                    (goto-char func-point)
-                    (forward-sexp)
-                    (point)))
-                 (source-info
-                  (elisp-dev-mcp--extract-source-region
-                   start-point end-point)))
+      ;; Find the start point including any header comments
+      (let* ((func-point (point))
+             (start-point
+              (elisp-dev-mcp--find-header-comment-start func-point))
+             (end-point
+              (progn
+                (goto-char func-point)
+                (forward-sexp)
+                (point)))
+             (source-info
+              (elisp-dev-mcp--extract-source-region
+               start-point end-point)))
 
-            ;; Return the result, with special handling for aliases
-            (if is-alias
-                (elisp-dev-mcp--process-alias-source
-                 (nth 0 source-info)
-                 fn-name
-                 aliased-to
-                 func-file
-                 (nth 1 source-info)
-                 (nth 2 source-info))
-              (elisp-dev-mcp--json-encode-source-location
-               (nth 0 source-info)
-               func-file
-               (nth 1 source-info)
-               (nth 2 source-info)))))))))
+        ;; Return the result, with special handling for aliases
+        (if is-alias
+            (elisp-dev-mcp--process-alias-source
+             (nth 0 source-info)
+             fn-name
+             aliased-to
+             func-file
+             (nth 1 source-info)
+             (nth 2 source-info))
+          (elisp-dev-mcp--json-encode-source-location
+           (nth 0 source-info)
+           func-file
+           (nth 1 source-info)
+           (nth 2 source-info)))))))
 
 (defun elisp-dev-mcp--extract-function-info (sym)
   "Extract function information for symbol SYM.
@@ -638,138 +587,71 @@ MCP Parameters:
         (format "Symbol '%s' not found in Elisp Info documentation"
                 symbol))))))
 
-(defun elisp-dev-mcp--library-name-p (name)
-  "Return non-nil if NAME is a library name, not a file path.
-Library names are non-blank strings without path separators.
-Strings containing '/' or '\\\\' are treated as paths, not library names."
-  (and (stringp name)
-       (not (string-blank-p name))
-       (not (file-name-absolute-p name))
-       (not (string-match-p "[/\\]" name))))
-
-(defun elisp-dev-mcp--resolve-library-to-source-path (library-name)
-  "Resolve LIBRARY-NAME to its source file path that exists on disk.
-
-Uses `locate-library' to find the library, then:
-  - Converts .elc → .el (source, not bytecode)
-  - Checks if .el exists, otherwise tries .el.gz
-
-Returns the actual file path (.el or .el.gz) that exists on disk.
-Throws an error if the library or source file is not found.
-
-Example transformations:
-  `locate-library' returns /path/file.el     → /path/file.el
-  `locate-library' returns /path/file.el.gz  → /path/file.el.gz
-  `locate-library' returns /path/file.elc    → /path/file.el (or .el.gz)
-  `locate-library' returns /path/file.elc.gz → /path/file.el (or .el.gz)"
-  (let ((library-path (locate-library library-name)))
-    (unless library-path
-      (mcp-server-lib-tool-throw
-       (format "Library not found: %s" library-name)))
-    ;; Remove .gz extension first if present
-    ;; This must be done before .elc conversion to handle .elc.gz correctly
-    (when (string-suffix-p ".gz" library-path)
-      (setq library-path (file-name-sans-extension library-path)))
-    ;; Convert .elc to .el if needed (after .gz removal)
-    (when (string-suffix-p ".elc" library-path)
-      (setq library-path
-            (concat (file-name-sans-extension library-path) ".el")))
-    ;; Find the actual source file that exists on disk
-    (let ((actual-file
-           (cond
-            ((file-exists-p library-path)
-             library-path)
-            ((file-exists-p (concat library-path ".gz"))
-             (concat library-path ".gz"))
-            (t
-             nil))))
-      (unless actual-file
-        (mcp-server-lib-tool-throw
-         (format
-          "Source file not found for library %s (tried %s and %s.gz)"
-          library-name library-path library-path)))
-      actual-file)))
-
-(defun elisp-dev-mcp--read-source-file (library-or-path)
+(defun elisp-dev-mcp--read-source-file (file-path)
   "Read Elisp source file from allowed locations.
-Accepts either a library name or absolute path via LIBRARY-OR-PATH.
-
-Library names (e.g., \"subr\", \"mcp-server-lib\") are resolved via
-`locate-library' and validated against the allowed directories.
-
-Absolute paths must be as returned by other elisp-dev tools.
-
+Accepts absolute FILE-PATH as returned by other elisp-dev tools.
 Handles both .el and .el.gz files transparently.
 
 MCP Parameters:
-  library-or-path - Library name (e.g., \"subr\") or absolute .el path"
+  file-path - Absolute path to .el file"
   (mcp-server-lib-with-error-handling
-   ;; 1. Resolve library name to absolute path if needed
-   (let ((file-path
-          (if (elisp-dev-mcp--library-name-p library-or-path)
-              (elisp-dev-mcp--resolve-library-to-source-path
-               library-or-path)
-            library-or-path)))
+   ;; 1. Validate input format
+   (unless (and (stringp file-path)
+                (file-name-absolute-p file-path)
+                (string-suffix-p ".el" file-path))
+     (mcp-server-lib-tool-throw
+      "Invalid path format: must be absolute path ending in .el"))
 
-     ;; 2. Validate input format
-     (unless (and (stringp file-path)
-                  (file-name-absolute-p file-path)
-                  (or (string-suffix-p ".el" file-path)
-                      (string-suffix-p ".el.gz" file-path)))
+   ;; 2. Check for path traversal
+   (when (string-match-p "\\.\\." file-path)
+     (mcp-server-lib-tool-throw
+      "Path contains illegal '..' traversal"))
+
+   ;; 3. Resolve symlinks and validate location
+   (let* ((true-path (file-truename file-path))
+          ;; Build list of allowed package directories
+          (allowed-dirs
+           (append
+            ;; Current package-user-dir
+            (when (boundp 'package-user-dir)
+              (list
+               (file-truename
+                (file-name-as-directory package-user-dir))))
+            ;; All dirs from package-directory-list
+            (mapcar #'file-truename package-directory-list)
+            ;; System lisp directory
+            (when elisp-dev-mcp--system-lisp-dir
+              (list (file-truename elisp-dev-mcp--system-lisp-dir)))))
+          ;; Check if file is under any allowed directory
+          (allowed-p
+           (cl-some
+            (lambda (dir)
+              (and dir (string-prefix-p dir true-path)))
+            allowed-dirs)))
+
+     (unless allowed-p
        (mcp-server-lib-tool-throw
-        "Invalid path format: must be absolute path ending in .el or .el.gz"))
+        "Access denied: path outside allowed directories"))
 
-     ;; 3. Check for path traversal
-     (when (string-match-p "\\.\\." file-path)
-       (mcp-server-lib-tool-throw
-        "Path contains illegal '..' traversal"))
+     ;; 4. Find actual file (.el or .el.gz)
+     (let ((actual-file
+            (cond
+             ((file-exists-p true-path)
+              true-path)
+             ((file-exists-p (concat true-path ".gz"))
+              (concat true-path ".gz"))
+             (t
+              nil))))
 
-     ;; 4. Resolve symlinks and validate location
-     (let* ((true-path (file-truename file-path))
-            ;; Build list of allowed package directories
-            (allowed-dirs
-             (append
-              ;; Current package-user-dir
-              (when (boundp 'package-user-dir)
-                (list
-                 (file-truename
-                  (file-name-as-directory package-user-dir))))
-              ;; All dirs from package-directory-list
-              (mapcar
-               (lambda (dir)
-                 (file-truename (file-name-as-directory dir)))
-               package-directory-list)
-              ;; System lisp directory
-              (when elisp-dev-mcp--system-lisp-dir
-                (list
-                 (file-truename
-                  (file-name-as-directory
-                   elisp-dev-mcp--system-lisp-dir))))
-              ;; User-configured additional directories
-              (mapcar
-               (lambda (dir)
-                 (file-truename (file-name-as-directory dir)))
-               elisp-dev-mcp-additional-allowed-dirs)))
-            ;; Check if file is under any allowed directory
-            (allowed-p
-             (cl-some
-              (lambda (dir)
-                (and dir (string-prefix-p dir true-path)))
-              allowed-dirs)))
-
-       (unless allowed-p
+       (unless actual-file
          (mcp-server-lib-tool-throw
-          "Access denied: path outside allowed directories"))
+          (format "File not found: %s (tried .el and .el.gz)"
+                  file-path)))
 
-       ;; 5. Verify file exists and read contents
-       (unless (file-exists-p true-path)
-         (mcp-server-lib-tool-throw
-          (format "File not found: %s" library-or-path)))
-
-       (elisp-dev-mcp--with-auto-compression
-         (with-temp-buffer
-           (insert-file-contents true-path)
-           (buffer-string)))))))
+       ;; 5. Read and return contents
+       (with-temp-buffer
+         (insert-file-contents actual-file)
+         (buffer-string))))))
 
 ;;;###autoload
 (defun elisp-dev-mcp-enable ()
@@ -931,37 +813,27 @@ Error cases:
    :server-id elisp-dev-mcp--server-id
    :description
    "Read Elisp source files from Emacs system directories or ELPA packages.
-Accepts either library names or absolute file paths.
+Designed to work with paths returned by other elisp-dev tools.
 
 Parameters:
-  library-or-path - Library name (e.g., \\='subr', \\='mcp-server-lib') or
-                    absolute path to .el file (string)
+  file-path - Absolute path to .el file (string)
 
-Input modes:
-1. Library names (recommended for built-in and installed packages):
-   - Simple names without path separators (e.g., \\='subr', \\='files')
-   - Resolved via Emacs locate-library function
-   - Examples: \\='subr', \\='mcp-server-lib', \\='org'
-
-2. Absolute paths (for compatibility with other elisp-dev tools):
-   - Full paths ending in .el (e.g., \\='/path/to/file.el')
-   - Returned by elisp-get-function-definition
-   - Examples: \\='/opt/homebrew/.../lisp/subr.el'
+Accepts paths like:
+- System Elisp files (from Emacs installation)
+- ELPA package files (from user-emacs-directory)
 
 Security:
-- Only reads from Emacs system lisp directories and ELPA directories
+- Only reads from Emacs system lisp directories and ELPA directory
 - Rejects paths with \"..\" traversal
 - Resolves symlinks to prevent escaping allowed directories
-- Library names must resolve to paths within allowed directories
 
 Features:
 - Transparently handles .el.gz compressed files
-- Works with both built-in Emacs libraries and installed packages
+- Works directly with paths from elisp-get-function-definition
 - Returns complete file contents as string
 
 Error cases:
-- Library not found (locate-library returns nil)
-- Invalid path format (paths must be absolute and end in .el)
+- Invalid path format
 - Path traversal attempts
 - Access outside allowed directories
 - File not found"
